@@ -972,7 +972,7 @@ wnck_window_set_window_type (WnckWindow *window, WnckWindowType wintype)
     atom = _wnck_atom_get ("_NET_WM_WINDOW_TYPE_UTILITY");
     break;
   case WNCK_WINDOW_SPLASHSCREEN:
-    atom = _wnck_atom_get ("_NET_WM_WINDOW_TYPE_SPLASHSCREEN");
+    atom = _wnck_atom_get ("_NET_WM_WINDOW_TYPE_SPLASH");
     break;
   default:
     return;
@@ -1769,9 +1769,8 @@ wnck_window_get_workspace (WnckWindow *window)
  * @window: a #WnckWindow.
  * @space: a #WnckWorkspace.
  *
- * Asks the window manager to move @window to @space.
- *
- * FIXME: what happens if @window is pinned?
+ * Asks the window manager to move @window to @space. If @window was pinned, it
+ * will also result in @window being visible only on @space.
  **/
 void
 wnck_window_move_to_workspace (WnckWindow    *window,
